You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@beehive.apache.org by ek...@apache.org on 2005/12/20 16:53:32 UTC

svn commit: r358023 - in /beehive/trunk: system-controls/ system-controls/src/webservice/control/ system-controls/src/webservice/control/org/apache/beehive/controls/system/webservice/generator/ system-controls/src/webservice/control/org/apache/beehive/...

Author: ekoneil
Date: Tue Dec 20 07:52:53 2005
New Revision: 358023

URL: http://svn.apache.org/viewcvs?rev=358023&view=rev
Log:
Bunch of WSM / WSC re-wiring.  This includes:

- renaming a "units" package to "tests" in WSC.  Everybody else does it this way...
- adding a strategy for discovering a BindingLookupService implementation to handle a specif web service stack's QName <> Java class mappings
- start of two new class <> qname JUnit tests
- make the XSD_* QNames public in SchemaTypesLookupStrategy
- rename BindingLookupService to BindingLookupStrategy

BB: self
Test: WSM && WSC pass


Added:
    beehive/trunk/system-controls/test/webservice/junit/src/org/apache/beehive/controls/system/webservice/tests/
      - copied from r357814, beehive/trunk/system-controls/test/webservice/junit/src/org/apache/beehive/controls/system/webservice/units/
    beehive/trunk/wsm/src/axis/META-INF/
    beehive/trunk/wsm/src/axis/META-INF/services/
    beehive/trunk/wsm/src/axis/META-INF/services/org.apache.beehive.wsm.databinding.BindingLookupStrategy
    beehive/trunk/wsm/src/axis/org/apache/beehive/wsm/axis/databinding/AxisLookupStrategy.java   (contents, props changed)
      - copied, changed from r357770, beehive/trunk/wsm/src/axis/org/apache/beehive/wsm/axis/databinding/AxisLookupService.java
    beehive/trunk/wsm/src/axis/org/apache/beehive/wsm/axis/databinding/TypeSystemLookupStrategy.java   (contents, props changed)
      - copied, changed from r357770, beehive/trunk/wsm/src/axis/org/apache/beehive/wsm/axis/databinding/TypeSystemLookupService.java
    beehive/trunk/wsm/src/core/org/apache/beehive/wsm/databinding/BindingLookupStrategy.java   (contents, props changed)
      - copied, changed from r357770, beehive/trunk/wsm/src/core/org/apache/beehive/wsm/databinding/BindingLookupService.java
    beehive/trunk/wsm/src/core/org/apache/beehive/wsm/databinding/xmlbeans/XmlBeanLookupStrategy.java   (contents, props changed)
      - copied, changed from r357770, beehive/trunk/wsm/src/core/org/apache/beehive/wsm/databinding/xmlbeans/XmlBeanLookupService.java
    beehive/trunk/wsm/src/core/org/apache/beehive/wsm/util/SchemaTypesLookupStrategy.java   (contents, props changed)
      - copied, changed from r357770, beehive/trunk/wsm/src/core/org/apache/beehive/wsm/util/SchemaTypesLookupService.java
    beehive/trunk/wsm/test/src/junit/org/apache/beehive/wsm/test/types/
    beehive/trunk/wsm/test/src/junit/org/apache/beehive/wsm/test/types/ClassToQNameTest.java   (with props)
    beehive/trunk/wsm/test/src/junit/org/apache/beehive/wsm/test/types/QNameToClassTest.java   (with props)
Removed:
    beehive/trunk/system-controls/test/webservice/junit/src/org/apache/beehive/controls/system/webservice/units/
    beehive/trunk/system-controls/test/webservice/webapp/web/WEB-INF/webservices/
    beehive/trunk/wsm/src/axis/org/apache/beehive/wsm/axis/databinding/AxisLookupService.java
    beehive/trunk/wsm/src/axis/org/apache/beehive/wsm/axis/databinding/TypeSystemLookupService.java
    beehive/trunk/wsm/src/core/org/apache/beehive/wsm/databinding/BindingLookupService.java
    beehive/trunk/wsm/src/core/org/apache/beehive/wsm/databinding/xmlbeans/XmlBeanLookupService.java
    beehive/trunk/wsm/src/core/org/apache/beehive/wsm/registration/
    beehive/trunk/wsm/src/core/org/apache/beehive/wsm/util/SchemaTypesLookupService.java
Modified:
    beehive/trunk/system-controls/build.xml
    beehive/trunk/system-controls/src/webservice/control/build.xml
    beehive/trunk/system-controls/src/webservice/control/org/apache/beehive/controls/system/webservice/generator/ServiceControlGenerator.java
    beehive/trunk/system-controls/src/webservice/control/org/apache/beehive/controls/system/webservice/jaxrpc/ServiceControlImpl.java
    beehive/trunk/system-controls/src/webservice/control/org/apache/beehive/controls/system/webservice/utils/TypeRegistrar.java
    beehive/trunk/system-controls/src/webservice/control/org/apache/beehive/controls/system/webservice/wsdl/WsdlOpReturnType.java
    beehive/trunk/system-controls/src/webservice/control/org/apache/beehive/controls/system/webservice/wsdl/WsdlOperation.java
    beehive/trunk/system-controls/src/webservice/jaxrpc-clients/axis/build.xml
    beehive/trunk/system-controls/src/webservice/jaxrpc-clients/axis/org/apache/beehive/controls/system/jaxrpc/AxisCall.java
    beehive/trunk/system-controls/src/webservice/jaxrpc-clients/axis/org/apache/beehive/controls/system/jaxrpc/AxisTypeRegistrar.java
    beehive/trunk/system-controls/test/webservice/junit/src/org/apache/beehive/controls/system/webservice/tests/holders/HolderUtilsTest.java
    beehive/trunk/system-controls/test/webservice/junit/src/org/apache/beehive/controls/system/webservice/tests/holders/MyClass.java
    beehive/trunk/system-controls/test/webservice/junit/src/org/apache/beehive/controls/system/webservice/tests/holders/MyClassArrayHolder.java
    beehive/trunk/system-controls/test/webservice/junit/src/org/apache/beehive/controls/system/webservice/tests/holders/MyClassListHolder.java
    beehive/trunk/system-controls/test/webservice/junit/src/org/apache/beehive/controls/system/webservice/tests/jcxgen/JcxGenFromDocLitBareWsdlTest.java
    beehive/trunk/system-controls/test/webservice/junit/src/org/apache/beehive/controls/system/webservice/tests/jcxgen/JcxGenFromDocLitWrapWsdlTest.java
    beehive/trunk/system-controls/test/webservice/junit/src/org/apache/beehive/controls/system/webservice/tests/jcxgen/JcxGenFromRpcLitWsdlTest.java
    beehive/trunk/system-controls/test/webservice/webapp/src/log4j.properties
    beehive/trunk/system-controls/test/webservice/webapp/tests/org/apache/beehive/controls/system/webservice/units/DataHandlerAttachementDocLitWrappedTest.java
    beehive/trunk/system-controls/test/webservice/webapp/tests/org/apache/beehive/controls/system/webservice/units/HeaderRpcEncEndpointTest.java
    beehive/trunk/wsm/build.xml
    beehive/trunk/wsm/src/axis/org/apache/beehive/wsm/axis/ServiceDescriptionFactory.java
    beehive/trunk/wsm/src/axis/org/apache/beehive/wsm/axis/tools/Wsdl2AJava.java
    beehive/trunk/wsm/src/core/org/apache/beehive/wsm/databinding/BindingLookupServiceFactory.java
    beehive/trunk/wsm/src/core/org/apache/beehive/wsm/model/wsdl/XmlBeanWSDLProcessor.java
    beehive/trunk/wsm/test/src/junit/org/apache/beehive/wsm/axis/handlers/FaultTest.java
    beehive/trunk/wsm/test/src/junit/org/apache/beehive/wsm/test/jsr181/wsdl/XmlBeanWSDLProcessorTest.java

Modified: beehive/trunk/system-controls/build.xml
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/build.xml?rev=358023&r1=358022&r2=358023&view=diff
==============================================================================
--- beehive/trunk/system-controls/build.xml (original)
+++ beehive/trunk/system-controls/build.xml Tue Dec 20 07:52:53 2005
@@ -37,7 +37,7 @@
         <ant dir="src/ejb" target="build" inheritAll="false"/>
         <ant dir="src/jdbc" target="build" inheritAll="false"/>
         <ant dir="src/jms" target="build" inheritAll="false"/>
-        <ant dir="src/webservice/control" target="build" inheritAll="false"/>
+        <ant dir="src/webservice" target="build" inheritAll="false"/>
 
         <echo message="--------------------------------------------------"/>
         <echo message="|      System Controls build ending              |"/>

Modified: beehive/trunk/system-controls/src/webservice/control/build.xml
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/src/webservice/control/build.xml?rev=358023&r1=358022&r2=358023&view=diff
==============================================================================
--- beehive/trunk/system-controls/src/webservice/control/build.xml (original)
+++ beehive/trunk/system-controls/src/webservice/control/build.xml Tue Dec 20 07:52:53 2005
@@ -1,4 +1,21 @@
 <?xml version="1.0" encoding="UTF-8" ?>
+<!--
+   Copyright 2004-2005 The Apache Software Foundation.
+
+   Licensed under the Apache License, Version 2.0 (the "License");
+   you may not use this file except in compliance with the License.
+   You may obtain a copy of the License at
+   
+       http://www.apache.org/licenses/LICENSE-2.0
+   
+   Unless required by applicable law or agreed to in writing, software
+   distributed under the License is distributed on an "AS IS" BASIS,
+   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+   See the License for the specific language governing permissions and
+   limitations under the License.
+  
+   $Header:$
+-->
 
 <project name="Beehive/SystemControls/WebService" default="build" basedir=".">
 
@@ -6,7 +23,6 @@
 
     <property name="module.name" value="webservice-control"/>
     <property name="module.dir" location="${src.dir}/webservice/control"/>
-    <property name="wsc.version" value="svn-snapshot"/>
 
     <path id="module.classpath">
         <path refid="wsm.dependency.path"/>

Modified: beehive/trunk/system-controls/src/webservice/control/org/apache/beehive/controls/system/webservice/generator/ServiceControlGenerator.java
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/src/webservice/control/org/apache/beehive/controls/system/webservice/generator/ServiceControlGenerator.java?rev=358023&r1=358022&r2=358023&view=diff
==============================================================================
--- beehive/trunk/system-controls/src/webservice/control/org/apache/beehive/controls/system/webservice/generator/ServiceControlGenerator.java (original)
+++ beehive/trunk/system-controls/src/webservice/control/org/apache/beehive/controls/system/webservice/generator/ServiceControlGenerator.java Tue Dec 20 07:52:53 2005
@@ -15,13 +15,24 @@
  */
 package org.apache.beehive.controls.system.webservice.generator;
 
+import javax.xml.namespace.QName;
+import java.io.File;
+import java.io.FileFilter;
+import java.io.FileNotFoundException;
+import java.io.PrintWriter;
+import java.io.UnsupportedEncodingException;
+import java.io.Writer;
+import java.lang.reflect.Array;
+import java.util.ArrayList;
+import java.util.List;
+import java.util.Properties;
 import org.apache.beehive.controls.system.webservice.wsdl.Wsdl;
 import org.apache.beehive.controls.system.webservice.wsdl.WsdlOpParameter;
 import org.apache.beehive.controls.system.webservice.wsdl.WsdlOpReturnType;
 import org.apache.beehive.controls.system.webservice.wsdl.WsdlOperation;
-import org.apache.beehive.wsm.axis.databinding.TypeSystemLookupService;
+import org.apache.beehive.wsm.axis.databinding.TypeSystemLookupStrategy;
 import org.apache.beehive.wsm.util.JavaClassUtils;
-import org.apache.beehive.wsm.databinding.BindingLookupService;
+import org.apache.beehive.wsm.databinding.BindingLookupStrategy;
 import org.apache.velocity.Template;
 import org.apache.velocity.VelocityContext;
 import org.apache.velocity.app.VelocityEngine;
@@ -30,22 +41,11 @@
 import org.apache.velocity.exception.ResourceNotFoundException;
 import org.apache.velocity.runtime.resource.loader.ClasspathResourceLoader;
 
-import javax.xml.namespace.QName;
-import java.io.File;
-import java.io.FileFilter;
-import java.io.FileNotFoundException;
-import java.io.PrintWriter;
-import java.io.UnsupportedEncodingException;
-import java.io.Writer;
-import java.lang.reflect.Array;
-import java.util.ArrayList;
-import java.util.List;
-import java.util.Properties;
-
 /**
  * Generate a service control from a WSDL using Velocity.
  */
 public final class ServiceControlGenerator {
+
     private static final FileFilter FILE_FILTER_WSDL = new WSDLFilter();
     private static final String WSDL_FILE_EXTENSION = "wsdl";
     private static final String SERVICE_CONTROL_FILE_EXTENSION = ".java";
@@ -97,10 +97,12 @@
 
         Wsdl wsdl = new Wsdl(wsdlFile.toURI());
         List<MethodInfo> methodList = buildMethodList(wsdl);
-
-        if (pkgName == null) {
+/*
+        if (pkgName == null)
+            pkgName = Utils.makePackageName(wsdl.getTargetNamespace());
+*/
+        if (pkgName == null)
             pkgName = GeneratorUtils.generatePackageName(wsdl.getTargetNamespace());
-        }
 
         if (_velocityEngine == null)
             initializeVelocity();
@@ -172,7 +174,7 @@
      */
     static private Writer getJcxWriter(File outputDir, String packageName, String serviceName)
             throws FileNotFoundException, UnsupportedEncodingException {
-        
+
         assert serviceName != null : "genJcxWriter: Service name can not be null!";
         assert packageName != null : "genJcxWriter: Package name can not be null!";
 
@@ -206,14 +208,18 @@
         ArrayList<MethodInfo> methodList = new ArrayList<MethodInfo>();
 
         for (WsdlOperation operation : wsdlDefinition.getOperations()) {
-            WsdlOpReturnType rtype = operation.getReturnType();
-            Class javaReturnType;
-            if (rtype != null) {
-                javaReturnType = getClass(rtype.getXmlType(), rtype.getItemXmlType(), rtype.isArray());
-            }
-            else {
-                javaReturnType = getClass(null, null, false);
-            }
+            WsdlOpReturnType returnType = operation.getReturnType();
+            Class javaReturnType = null;
+
+            System.out.println("=== return type is: " + (returnType != null ? returnType.getXmlType() : "null"));
+
+            if (returnType != null)
+                javaReturnType = getClass(returnType.getXmlType(),
+                                          returnType.getItemXmlType(),
+                                          returnType.isArray());
+            else javaReturnType = getClass(null, null, false);
+
+            System.out.println("=== java class type: " + javaReturnType);
 
             MethodInfo m = new MethodInfo();
             m.setMethodName(operation.getOperationName().getLocalPart());
@@ -242,9 +248,9 @@
             return void.class;
         }
 
-        BindingLookupService bindingLookupService = TypeSystemLookupService.getInstance();
+        BindingLookupStrategy bindingLookupStrategy = TypeSystemLookupStrategy.getInstance();
         if (!isArray) {
-            return bindingLookupService.qname2class(xmlType);
+            return bindingLookupStrategy.qname2class(xmlType);
         }
 
         //
@@ -253,10 +259,10 @@
         //
         Class javaReturnType;
         if (itemXmlType != null) {
-            javaReturnType = bindingLookupService.qname2class(itemXmlType);
+            javaReturnType = bindingLookupStrategy.qname2class(itemXmlType);
         }
         else {
-            javaReturnType = bindingLookupService.qname2class(xmlType);
+            javaReturnType = bindingLookupStrategy.qname2class(xmlType);
         }
 
         Object o = Array.newInstance(javaReturnType, 1);

Modified: beehive/trunk/system-controls/src/webservice/control/org/apache/beehive/controls/system/webservice/jaxrpc/ServiceControlImpl.java
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/src/webservice/control/org/apache/beehive/controls/system/webservice/jaxrpc/ServiceControlImpl.java?rev=358023&r1=358022&r2=358023&view=diff
==============================================================================
--- beehive/trunk/system-controls/src/webservice/control/org/apache/beehive/controls/system/webservice/jaxrpc/ServiceControlImpl.java (original)
+++ beehive/trunk/system-controls/src/webservice/control/org/apache/beehive/controls/system/webservice/jaxrpc/ServiceControlImpl.java Tue Dec 20 07:52:53 2005
@@ -15,6 +15,16 @@
  */
 package org.apache.beehive.controls.system.webservice.jaxrpc;
 
+import java.lang.reflect.Method;
+import java.net.MalformedURLException;
+import java.net.URL;
+import java.util.HashMap;
+import javax.xml.namespace.QName;
+import javax.xml.rpc.Service;
+import javax.xml.rpc.ServiceException;
+import javax.xml.rpc.ServiceFactory;
+import javax.xml.rpc.handler.HandlerInfo;
+
 import org.apache.beehive.controls.api.ControlException;
 import org.apache.beehive.controls.api.bean.ControlImplementation;
 import org.apache.beehive.controls.api.bean.Extensible;
@@ -29,21 +39,10 @@
 import org.apache.commons.logging.LogFactory;
 import org.w3c.dom.Element;
 
-import javax.jws.soap.SOAPBinding;
-import javax.xml.namespace.QName;
-import javax.xml.rpc.Service;
-import javax.xml.rpc.ServiceException;
-import javax.xml.rpc.ServiceFactory;
-import javax.xml.rpc.handler.HandlerInfo;
-import java.lang.reflect.Method;
-import java.net.MalformedURLException;
-import java.net.URL;
-import java.rmi.RemoteException;
-import java.util.HashMap;
-
 @ControlImplementation
-public class ServiceControlImpl implements ServiceControl, Extensible, java.io.Serializable
-{
+public class ServiceControlImpl
+    implements ServiceControl, Extensible, java.io.Serializable {
+
     private static final int TIMOUT_DEFAULT = 1000;
     private static final Log LOGGER = LogFactory.getLog(ServiceControlImpl.class);
 
@@ -83,12 +82,10 @@
     @EventHandler(field = "_resourceContext", eventSet = ResourceContext.ResourceEvents.class, eventName = "onAcquire")
     public void onAquire() {
 
-        if (LOGGER.isDebugEnabled()) {
+        if (LOGGER.isDebugEnabled())
             LOGGER.debug("Enter: onAquire()");
-        }
 
         if (_service == null) {
-
             ServiceControl.ServiceFactoryProvider sfp =
                     _context.getControlPropertySet(ServiceControl.ServiceFactoryProvider.class);
             _serviceFactoryClassName = sfp.value().getServiceFactoryClassName();
@@ -103,9 +100,8 @@
     @EventHandler(field = "_resourceContext", eventSet = ResourceContext.ResourceEvents.class, eventName = "onRelease")
     public void onRelease() {
 
-        if (LOGGER.isDebugEnabled()) {
+        if (LOGGER.isDebugEnabled())
             LOGGER.debug("Enter: onRelease()");
-        }
 
         _service = null;
         _callCache = null;
@@ -141,8 +137,10 @@
             getCallCache().put(opName.value(), call);
         }
 
-        call.setUserDefinedProperties(getWsdlPort(), getEndPoint().toExternalForm(),
-                getUsername(), getPassword());
+        call.setUserDefinedProperties(getWsdlPort(),
+                                      getEndPoint().toExternalForm(),
+                                      getUsername(),
+                                      getPassword());
 
         return call.invoke(args);
     }
@@ -161,7 +159,7 @@
      * @param endPoint The endPoint to set.
      */
     public void setEndPoint(URL endPoint) {
-        this._endPoint = endPoint;
+        _endPoint = endPoint;
     }
 
     /**
@@ -175,7 +173,7 @@
      * @param password The password to set.
      */
     public void setPassword(String password) {
-        this._password = password;
+        _password = password;
     }
 
     /**
@@ -189,7 +187,7 @@
      * @param timeout The timeout to set.
      */
     public void setTimeout(int timeout) {
-        this._timeout = timeout;
+        _timeout = timeout;
     }
 
     /**
@@ -203,7 +201,7 @@
      * @param username The username to set.
      */
     public void setUsername(String username) {
-        this._username = username;
+        _username = username;
     }
 
     /**
@@ -218,7 +216,7 @@
      */
     public void setWsdlPort(QName wsdlPort) {
         _wsdl.setPort(wsdlPort);
-        this._wsdlPort = wsdlPort;
+        _wsdlPort = wsdlPort;
     }
 
     /**

Modified: beehive/trunk/system-controls/src/webservice/control/org/apache/beehive/controls/system/webservice/utils/TypeRegistrar.java
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/src/webservice/control/org/apache/beehive/controls/system/webservice/utils/TypeRegistrar.java?rev=358023&r1=358022&r2=358023&view=diff
==============================================================================
--- beehive/trunk/system-controls/src/webservice/control/org/apache/beehive/controls/system/webservice/utils/TypeRegistrar.java (original)
+++ beehive/trunk/system-controls/src/webservice/control/org/apache/beehive/controls/system/webservice/utils/TypeRegistrar.java Tue Dec 20 07:52:53 2005
@@ -33,7 +33,7 @@
 import javax.xml.rpc.encoding.XMLType;
 import javax.xml.rpc.holders.Holder;
 
-import org.apache.beehive.wsm.databinding.BindingLookupService;
+import org.apache.beehive.wsm.databinding.BindingLookupStrategy;
 import org.apache.beehive.wsm.databinding.GenericHolder;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
@@ -44,14 +44,14 @@
 
     /* todo: need to figure out how to protect these since they're used by subclasses */
     protected TypeMapping mTypeMapping;
-    protected BindingLookupService lookupService;
+    protected BindingLookupStrategy _lookupStrategy;
 
     /**
      */
-    public TypeRegistrar(TypeMapping typeMapping, BindingLookupService lookupService) {
+    public TypeRegistrar(TypeMapping typeMapping, BindingLookupStrategy lookupStrategy) {
         super();
         mTypeMapping = typeMapping;
-        this.lookupService = lookupService;
+        this._lookupStrategy = lookupStrategy;
     }
 
     /**
@@ -61,10 +61,10 @@
     public QName registerType(Class cls, SOAPBinding.Style style, SOAPBinding.Use use) {
         QName q;
         if(SOAPBinding.Use.ENCODED == use && cls.isArray()) {
-            q = lookupService.class2qname(cls.getComponentType());
+            q = _lookupStrategy.class2qname(cls.getComponentType());
         }
         else {
-            q = lookupService.class2qname(cls);
+            q = _lookupStrategy.class2qname(cls);
         }
         return registerType(cls, q, style, use);
     }

Modified: beehive/trunk/system-controls/src/webservice/control/org/apache/beehive/controls/system/webservice/wsdl/WsdlOpReturnType.java
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/src/webservice/control/org/apache/beehive/controls/system/webservice/wsdl/WsdlOpReturnType.java?rev=358023&r1=358022&r2=358023&view=diff
==============================================================================
--- beehive/trunk/system-controls/src/webservice/control/org/apache/beehive/controls/system/webservice/wsdl/WsdlOpReturnType.java (original)
+++ beehive/trunk/system-controls/src/webservice/control/org/apache/beehive/controls/system/webservice/wsdl/WsdlOpReturnType.java Tue Dec 20 07:52:53 2005
@@ -15,7 +15,6 @@
  *
  * $Header:$
  */
-
 package org.apache.beehive.controls.system.webservice.wsdl;
 
 import javax.xml.namespace.QName;
@@ -27,8 +26,7 @@
 {
     protected QName _xmlType;
     protected boolean _isArray;
-
-    // used for the xmlType of an Array's items
+    /* used for the xmlType of an Array's items */
     protected QName _itemXmlType;
 
     /**

Modified: beehive/trunk/system-controls/src/webservice/control/org/apache/beehive/controls/system/webservice/wsdl/WsdlOperation.java
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/src/webservice/control/org/apache/beehive/controls/system/webservice/wsdl/WsdlOperation.java?rev=358023&r1=358022&r2=358023&view=diff
==============================================================================
--- beehive/trunk/system-controls/src/webservice/control/org/apache/beehive/controls/system/webservice/wsdl/WsdlOperation.java (original)
+++ beehive/trunk/system-controls/src/webservice/control/org/apache/beehive/controls/system/webservice/wsdl/WsdlOperation.java Tue Dec 20 07:52:53 2005
@@ -1,3 +1,20 @@
+/*
+ * Copyright 2005 The Apache Software Foundation.
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ *
+ * $Header:$
+ */
 package org.apache.beehive.controls.system.webservice.wsdl;
 
 import javax.wsdl.Binding;

Modified: beehive/trunk/system-controls/src/webservice/jaxrpc-clients/axis/build.xml
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/src/webservice/jaxrpc-clients/axis/build.xml?rev=358023&r1=358022&r2=358023&view=diff
==============================================================================
--- beehive/trunk/system-controls/src/webservice/jaxrpc-clients/axis/build.xml (original)
+++ beehive/trunk/system-controls/src/webservice/jaxrpc-clients/axis/build.xml Tue Dec 20 07:52:53 2005
@@ -1,12 +1,28 @@
 <?xml version="1.0" encoding="UTF-8" ?>
 
-<project name="Beehive/SystemControls/WebService/JaxRpcClient" default="build" basedir=".">
+<!--
+   Copyright 2004-2005 The Apache Software Foundation.
+
+   Licensed under the Apache License, Version 2.0 (the "License");
+   you may not use this file except in compliance with the License.
+   You may obtain a copy of the License at
+   
+       http://www.apache.org/licenses/LICENSE-2.0
+   
+   Unless required by applicable law or agreed to in writing, software
+   distributed under the License is distributed on an "AS IS" BASIS,
+   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+   See the License for the specific language governing permissions and
+   limitations under the License.
+  
+   $Header:$
+-->
+<project name="Beehive/SystemControls/WebService/AxisSupport" default="build" basedir=".">
 
     <import file="../../../../systemcontrols-imports.xml"/>
 
     <property name="module.name" value="jaxrpc-client"/>
     <property name="module.dir" location="${src.dir}/webservice/jaxrpc-clients/axis"/>
-    <property name="wsc.version" value="svn-snapshot"/>
 
     <path id="module.classpath">
         <path location="${classes.dir}/webservice-control"/>
@@ -22,18 +38,17 @@
     <target name="build" description="Builds axis client support for service control.">
 
         <echo message="--------------------------------------------------"/>
-        <echo message="|      AXIS client support build starting        |"/>
+        <echo message="|      Axis 1.x client support build starting    |"/>
         <echo message="--------------------------------------------------"/>
 
         <javac srcdir="${module.dir}"
              destdir="${classes.dir}/webservice-control"
              classpathref="module.classpath"
              debug="${compiler.debug}"
-             nowarn="${compiler.nowarn}">
-        </javac>
+             nowarn="${compiler.nowarn}"/>
 
         <echo message="--------------------------------------------------"/>
-        <echo message="|      AXIS client support build complete        |"/>
+        <echo message="|      Axis 1.x client support build complete    |"/>
         <echo message="--------------------------------------------------"/>
     </target>
 </project>

Modified: beehive/trunk/system-controls/src/webservice/jaxrpc-clients/axis/org/apache/beehive/controls/system/jaxrpc/AxisCall.java
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/src/webservice/jaxrpc-clients/axis/org/apache/beehive/controls/system/jaxrpc/AxisCall.java?rev=358023&r1=358022&r2=358023&view=diff
==============================================================================
--- beehive/trunk/system-controls/src/webservice/jaxrpc-clients/axis/org/apache/beehive/controls/system/jaxrpc/AxisCall.java (original)
+++ beehive/trunk/system-controls/src/webservice/jaxrpc-clients/axis/org/apache/beehive/controls/system/jaxrpc/AxisCall.java Tue Dec 20 07:52:53 2005
@@ -29,14 +29,14 @@
 import org.apache.beehive.controls.system.webservice.wsdl.WsdlOpParameter;
 import org.apache.beehive.controls.system.webservice.wsdl.WsdlOperation;
 import org.apache.beehive.controls.system.webservice.jaxrpc.GenericCall;
-import org.apache.beehive.wsm.axis.databinding.TypeSystemLookupService;
-import org.apache.beehive.wsm.databinding.BindingLookupService;
+import org.apache.beehive.wsm.axis.databinding.TypeSystemLookupStrategy;
+import org.apache.beehive.wsm.databinding.BindingLookupStrategy;
 
 /**
  * This is the AXIS 1.2 implementation of the call abstraction layer of the service control.
  */
-public final class AxisCall extends GenericCall
-{
+public final class AxisCall
+    extends GenericCall {
 
     private AxisTypeRegistrar _typeRegistrar;
 
@@ -49,10 +49,10 @@
     public AxisCall(Service service)
         throws ServiceException {
         TypeMapping typeMapping = service.getTypeMappingRegistry().getDefaultTypeMapping();
-        BindingLookupService bindingLookupService = TypeSystemLookupService.getInstance();
+        BindingLookupStrategy bindingLookupStrategy = TypeSystemLookupStrategy.getInstance();
 
         _call = service.createCall();
-        _typeRegistrar = new AxisTypeRegistrar(typeMapping, bindingLookupService);
+        _typeRegistrar = new AxisTypeRegistrar(typeMapping, bindingLookupStrategy);
     }
 
     /* -----------------------------   Protected Methods ------------------------- */
@@ -66,11 +66,14 @@
      * @param style         SOAPBinding style.
      * @param use           SOAPBinding use.
      */
-    protected void addFault(QName faultName, QName xmlType, boolean isComplexType,
-                            WsdlOperation.SOAPBindingStyle style, WsdlOperation.SOAPBindingUse use) {
+    protected void addFault(QName faultName,
+                            QName xmlType,
+                            boolean isComplexType,
+                            WsdlOperation.SOAPBindingStyle style,
+                            WsdlOperation.SOAPBindingUse use) {
 
-        BindingLookupService bindingLookupService = TypeSystemLookupService.getInstance();
-        Class javaType = bindingLookupService.qname2class(xmlType);
+        BindingLookupStrategy bindingLookupStrategy = TypeSystemLookupStrategy.getInstance();
+        Class javaType = bindingLookupStrategy.qname2class(xmlType);
 
         QName registeredTypeQName = registerType(javaType, xmlType, style, use);
         ((org.apache.axis.client.Call) _call).addFault(faultName, javaType, registeredTypeQName, isComplexType);
@@ -88,23 +91,17 @@
     protected void addParameter(QName paramName, Class paramClass, QName xmlType, WsdlOpParameter.ParameterMode mode, boolean isHeader) {
 
         ParameterMode jaxrpcMode;
-        if (mode == WsdlOpParameter.ParameterMode.IN) {
+        if (mode == WsdlOpParameter.ParameterMode.IN)
             jaxrpcMode = ParameterMode.IN;
-        }
-        else if (mode == WsdlOpParameter.ParameterMode.INOUT) {
+        else if (mode == WsdlOpParameter.ParameterMode.INOUT)
             jaxrpcMode = ParameterMode.INOUT;
-        }
-        else {
+        else
             jaxrpcMode = ParameterMode.OUT;
-        }
 
-        if (isHeader) {
-            ((org.apache.axis.client.Call) _call).addParameterAsHeader(paramName, xmlType, paramClass,
-                                                                       jaxrpcMode, jaxrpcMode);
-        }
-        else {
-            ((org.apache.axis.client.Call) _call).addParameter(paramName, xmlType, paramClass, jaxrpcMode);
-        }
+        org.apache.axis.client.Call axisCall = (org.apache.axis.client.Call)_call;
+        if (isHeader)
+            axisCall.addParameterAsHeader(paramName, xmlType, paramClass, jaxrpcMode, jaxrpcMode);
+        else axisCall.addParameter(paramName, xmlType, paramClass, jaxrpcMode);
     }
 
     /**
@@ -116,9 +113,10 @@
      * @param use
      * @return QName
      */
-    protected QName registerType(Class typeClass, QName xmlName,
-                                 WsdlOperation.SOAPBindingStyle style, WsdlOperation.SOAPBindingUse use) {
-
+    protected QName registerType(Class typeClass,
+                                 QName xmlName,
+                                 WsdlOperation.SOAPBindingStyle style,
+                                 WsdlOperation.SOAPBindingUse use) {
         SOAPBinding.Style jaxrpcStyle =
                 (style == WsdlOperation.SOAPBindingStyle.DOCUMENT) ? SOAPBinding.Style.DOCUMENT : SOAPBinding.Style.RPC;
         SOAPBinding.Use jaxrpcUse =
@@ -151,12 +149,9 @@
      * @param xmlReturnType Xml return type.
      */
     protected void setReturnType(Class returnType, QName xmlReturnType) {
-        if (!_isOneWay && returnType != void.class) {
+        if (!_isOneWay && returnType != void.class)
             super.setReturnType(returnType, xmlReturnType);
-        }
-        else {
-            _call.setReturnType(XMLType.AXIS_VOID);
-        }
+        else _call.setReturnType(XMLType.AXIS_VOID);
     }
 
     /**

Modified: beehive/trunk/system-controls/src/webservice/jaxrpc-clients/axis/org/apache/beehive/controls/system/jaxrpc/AxisTypeRegistrar.java
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/src/webservice/jaxrpc-clients/axis/org/apache/beehive/controls/system/jaxrpc/AxisTypeRegistrar.java?rev=358023&r1=358022&r2=358023&view=diff
==============================================================================
--- beehive/trunk/system-controls/src/webservice/jaxrpc-clients/axis/org/apache/beehive/controls/system/jaxrpc/AxisTypeRegistrar.java (original)
+++ beehive/trunk/system-controls/src/webservice/jaxrpc-clients/axis/org/apache/beehive/controls/system/jaxrpc/AxisTypeRegistrar.java Tue Dec 20 07:52:53 2005
@@ -38,7 +38,7 @@
 import org.apache.beehive.wsm.axis.util.encoding.XmlBeanDeserializerFactory;
 import org.apache.beehive.wsm.axis.util.encoding.XmlBeanSerializerFactory;
 import org.apache.beehive.wsm.axis.registration.AxisTypeMappingMetaData;
-import org.apache.beehive.wsm.databinding.BindingLookupService;
+import org.apache.beehive.wsm.databinding.BindingLookupStrategy;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
@@ -47,8 +47,8 @@
 
     private static Log LOGGER = LogFactory.getLog(AxisTypeRegistrar.class);
 
-    public AxisTypeRegistrar(TypeMapping tm, BindingLookupService lookupService) {
-        super(tm, lookupService);
+    public AxisTypeRegistrar(TypeMapping tm, BindingLookupStrategy lookupStrategy) {
+        super(tm, lookupStrategy);
     }
 
     public QName getVoidType() {
@@ -163,9 +163,9 @@
 
     protected void registerClassAsSoapEncodedArray(Class cls, QName q) {
         LOGGER.debug("Assigned Array Serialization to  class: " + cls.getCanonicalName()
-            + " qname:" + q + " Array element qname: " + lookupService.class2qname(cls.getComponentType()));
+            + " qname:" + q + " Array element qname: " + _lookupStrategy.class2qname(cls.getComponentType()));
 
-        mTypeMapping.register(cls, q, new ArraySerializerFactory(lookupService.class2qname(cls.getComponentType())),
+        mTypeMapping.register(cls, q, new ArraySerializerFactory(_lookupStrategy.class2qname(cls.getComponentType())),
                               new ArrayDeserializerFactory());
     }
 

Modified: beehive/trunk/system-controls/test/webservice/junit/src/org/apache/beehive/controls/system/webservice/tests/holders/HolderUtilsTest.java
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/test/webservice/junit/src/org/apache/beehive/controls/system/webservice/tests/holders/HolderUtilsTest.java?rev=358023&r1=357814&r2=358023&view=diff
==============================================================================
--- beehive/trunk/system-controls/test/webservice/junit/src/org/apache/beehive/controls/system/webservice/tests/holders/HolderUtilsTest.java (original)
+++ beehive/trunk/system-controls/test/webservice/junit/src/org/apache/beehive/controls/system/webservice/tests/holders/HolderUtilsTest.java Tue Dec 20 07:52:53 2005
@@ -15,7 +15,7 @@
  * limitations under the License.
  * 
  */
-package org.apache.beehive.controls.system.webservice.units.holders;
+package org.apache.beehive.controls.system.webservice.tests.holders;
 
 import junit.framework.Test;
 import junit.framework.TestCase;
@@ -131,7 +131,7 @@
     }
 
     public static Test suite() {
-        return new TestSuite(org.apache.beehive.controls.system.webservice.units.holders.HolderUtilsTest.class);
+        return new TestSuite(org.apache.beehive.controls.system.webservice.tests.holders.HolderUtilsTest.class);
     }
 
     public static void main(String[] args) {

Modified: beehive/trunk/system-controls/test/webservice/junit/src/org/apache/beehive/controls/system/webservice/tests/holders/MyClass.java
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/test/webservice/junit/src/org/apache/beehive/controls/system/webservice/tests/holders/MyClass.java?rev=358023&r1=357814&r2=358023&view=diff
==============================================================================
--- beehive/trunk/system-controls/test/webservice/junit/src/org/apache/beehive/controls/system/webservice/tests/holders/MyClass.java (original)
+++ beehive/trunk/system-controls/test/webservice/junit/src/org/apache/beehive/controls/system/webservice/tests/holders/MyClass.java Tue Dec 20 07:52:53 2005
@@ -1,4 +1,4 @@
-package org.apache.beehive.controls.system.webservice.units.holders;
+package org.apache.beehive.controls.system.webservice.tests.holders;
 
 public class MyClass {
 	public String name;

Modified: beehive/trunk/system-controls/test/webservice/junit/src/org/apache/beehive/controls/system/webservice/tests/holders/MyClassArrayHolder.java
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/test/webservice/junit/src/org/apache/beehive/controls/system/webservice/tests/holders/MyClassArrayHolder.java?rev=358023&r1=357814&r2=358023&view=diff
==============================================================================
--- beehive/trunk/system-controls/test/webservice/junit/src/org/apache/beehive/controls/system/webservice/tests/holders/MyClassArrayHolder.java (original)
+++ beehive/trunk/system-controls/test/webservice/junit/src/org/apache/beehive/controls/system/webservice/tests/holders/MyClassArrayHolder.java Tue Dec 20 07:52:53 2005
@@ -1,4 +1,4 @@
-package org.apache.beehive.controls.system.webservice.units.holders;
+package org.apache.beehive.controls.system.webservice.tests.holders;
 
 import javax.xml.rpc.holders.Holder;
 

Modified: beehive/trunk/system-controls/test/webservice/junit/src/org/apache/beehive/controls/system/webservice/tests/holders/MyClassListHolder.java
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/test/webservice/junit/src/org/apache/beehive/controls/system/webservice/tests/holders/MyClassListHolder.java?rev=358023&r1=357814&r2=358023&view=diff
==============================================================================
--- beehive/trunk/system-controls/test/webservice/junit/src/org/apache/beehive/controls/system/webservice/tests/holders/MyClassListHolder.java (original)
+++ beehive/trunk/system-controls/test/webservice/junit/src/org/apache/beehive/controls/system/webservice/tests/holders/MyClassListHolder.java Tue Dec 20 07:52:53 2005
@@ -1,9 +1,10 @@
-package org.apache.beehive.controls.system.webservice.units.holders;
+package org.apache.beehive.controls.system.webservice.tests.holders;
 
 import javax.xml.rpc.holders.Holder;
 import java.util.List;
 
-public class MyClassListHolder implements Holder {
+public class MyClassListHolder
+    implements Holder {
 
         public List value;
 

Modified: beehive/trunk/system-controls/test/webservice/junit/src/org/apache/beehive/controls/system/webservice/tests/jcxgen/JcxGenFromDocLitBareWsdlTest.java
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/test/webservice/junit/src/org/apache/beehive/controls/system/webservice/tests/jcxgen/JcxGenFromDocLitBareWsdlTest.java?rev=358023&r1=357814&r2=358023&view=diff
==============================================================================
--- beehive/trunk/system-controls/test/webservice/junit/src/org/apache/beehive/controls/system/webservice/tests/jcxgen/JcxGenFromDocLitBareWsdlTest.java (original)
+++ beehive/trunk/system-controls/test/webservice/junit/src/org/apache/beehive/controls/system/webservice/tests/jcxgen/JcxGenFromDocLitBareWsdlTest.java Tue Dec 20 07:52:53 2005
@@ -15,7 +15,7 @@
  * limitations under the License.
  *
  */
-package org.apache.beehive.controls.system.webservice.units.jcxgen;
+package org.apache.beehive.controls.system.webservice.tests.jcxgen;
 
 import java.lang.reflect.Method;
 

Modified: beehive/trunk/system-controls/test/webservice/junit/src/org/apache/beehive/controls/system/webservice/tests/jcxgen/JcxGenFromDocLitWrapWsdlTest.java
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/test/webservice/junit/src/org/apache/beehive/controls/system/webservice/tests/jcxgen/JcxGenFromDocLitWrapWsdlTest.java?rev=358023&r1=357814&r2=358023&view=diff
==============================================================================
--- beehive/trunk/system-controls/test/webservice/junit/src/org/apache/beehive/controls/system/webservice/tests/jcxgen/JcxGenFromDocLitWrapWsdlTest.java (original)
+++ beehive/trunk/system-controls/test/webservice/junit/src/org/apache/beehive/controls/system/webservice/tests/jcxgen/JcxGenFromDocLitWrapWsdlTest.java Tue Dec 20 07:52:53 2005
@@ -15,7 +15,7 @@
  * limitations under the License.
  * 
  */
-package org.apache.beehive.controls.system.webservice.units.jcxgen;
+package org.apache.beehive.controls.system.webservice.tests.jcxgen;
 
 import junit.framework.Test;
 import junit.framework.TestCase;

Modified: beehive/trunk/system-controls/test/webservice/junit/src/org/apache/beehive/controls/system/webservice/tests/jcxgen/JcxGenFromRpcLitWsdlTest.java
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/test/webservice/junit/src/org/apache/beehive/controls/system/webservice/tests/jcxgen/JcxGenFromRpcLitWsdlTest.java?rev=358023&r1=357814&r2=358023&view=diff
==============================================================================
--- beehive/trunk/system-controls/test/webservice/junit/src/org/apache/beehive/controls/system/webservice/tests/jcxgen/JcxGenFromRpcLitWsdlTest.java (original)
+++ beehive/trunk/system-controls/test/webservice/junit/src/org/apache/beehive/controls/system/webservice/tests/jcxgen/JcxGenFromRpcLitWsdlTest.java Tue Dec 20 07:52:53 2005
@@ -14,7 +14,7 @@
  * limitations under the License.
  * 
  */
-package org.apache.beehive.controls.system.webservice.units.jcxgen;
+package org.apache.beehive.controls.system.webservice.tests.jcxgen;
 
 import junit.framework.Test;
 import junit.framework.TestCase;

Modified: beehive/trunk/system-controls/test/webservice/webapp/src/log4j.properties
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/test/webservice/webapp/src/log4j.properties?rev=358023&r1=358022&r2=358023&view=diff
==============================================================================
--- beehive/trunk/system-controls/test/webservice/webapp/src/log4j.properties (original)
+++ beehive/trunk/system-controls/test/webservice/webapp/src/log4j.properties Tue Dec 20 07:52:53 2005
@@ -1,6 +1,5 @@
 # Set root category priority to INFO and its only appender to CONSOLE.
 log4j.rootCategory=INFO, CONSOLE
-#log4j.rootCategory=INFO, CONSOLE, LOGFILE
 
 # Set the enterprise logger category to FATAL and its only appender to CONSOLE.
 log4j.logger.org.apache.axis.enterprise=FATAL, CONSOLE

Modified: beehive/trunk/system-controls/test/webservice/webapp/tests/org/apache/beehive/controls/system/webservice/units/DataHandlerAttachementDocLitWrappedTest.java
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/test/webservice/webapp/tests/org/apache/beehive/controls/system/webservice/units/DataHandlerAttachementDocLitWrappedTest.java?rev=358023&r1=358022&r2=358023&view=diff
==============================================================================
--- beehive/trunk/system-controls/test/webservice/webapp/tests/org/apache/beehive/controls/system/webservice/units/DataHandlerAttachementDocLitWrappedTest.java (original)
+++ beehive/trunk/system-controls/test/webservice/webapp/tests/org/apache/beehive/controls/system/webservice/units/DataHandlerAttachementDocLitWrappedTest.java Tue Dec 20 07:52:53 2005
@@ -15,16 +15,17 @@
  */
 package org.apache.beehive.controls.system.webservice.units;
 
+import javax.activation.DataHandler;
+import java.io.ByteArrayOutputStream;
+import java.io.InputStream;
+import java.awt.Component;
+import java.awt.MediaTracker;
+import java.awt.Toolkit;
+import java.awt.Image;
 import junit.framework.Test;
 import junit.framework.TestSuite;
 import org.apache.beehive.controls.api.bean.Control;
 import org.apache.beehive.controls.system.webservice.units.utils.ControlTestCase;
-
-import javax.activation.DataHandler;
-import java.awt.*;
-import java.io.ByteArrayOutputStream;
-import java.io.InputStream;
-
 
 public class DataHandlerAttachementDocLitWrappedTest
         extends ControlTestCase {

Modified: beehive/trunk/system-controls/test/webservice/webapp/tests/org/apache/beehive/controls/system/webservice/units/HeaderRpcEncEndpointTest.java
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/test/webservice/webapp/tests/org/apache/beehive/controls/system/webservice/units/HeaderRpcEncEndpointTest.java?rev=358023&r1=358022&r2=358023&view=diff
==============================================================================
--- beehive/trunk/system-controls/test/webservice/webapp/tests/org/apache/beehive/controls/system/webservice/units/HeaderRpcEncEndpointTest.java (original)
+++ beehive/trunk/system-controls/test/webservice/webapp/tests/org/apache/beehive/controls/system/webservice/units/HeaderRpcEncEndpointTest.java Tue Dec 20 07:52:53 2005
@@ -17,19 +17,16 @@
  */
 package org.apache.beehive.controls.system.webservice.units;
 
+import javax.xml.rpc.holders.IntHolder;
+import javax.xml.rpc.holders.StringHolder;
 import junit.framework.Test;
 import junit.framework.TestSuite;
 import org.apache.beehive.controls.api.bean.Control;
 import org.apache.beehive.controls.system.webservice.units.utils.ControlTestCase;
 import org.apache.beehive.wsm.databinding.GenericHolder;
-import org.apache.log4j.Logger;
 import test.HeaderRpcLitEndpointService;
 
-import javax.xml.rpc.holders.IntHolder;
-import javax.xml.rpc.holders.StringHolder;
-
 public class HeaderRpcEncEndpointTest extends ControlTestCase {
-    static Logger logger = Logger.getLogger(HeaderRpcEncEndpointTest.class);
 
     @Control
     public HeaderRpcLitEndpointService client;

Modified: beehive/trunk/wsm/build.xml
URL: http://svn.apache.org/viewcvs/beehive/trunk/wsm/build.xml?rev=358023&r1=358022&r2=358023&view=diff
==============================================================================
--- beehive/trunk/wsm/build.xml (original)
+++ beehive/trunk/wsm/build.xml Tue Dec 20 07:52:53 2005
@@ -224,6 +224,7 @@
             <fileset refid="jsr173.fileset"/>
             <fileset refid="controls.fileset"/>
             <fileset refid="velocity.fileset"/>
+            <fileset refid="commons-discovery.fileset"/>
         </copy>
     </target>
                 

Added: beehive/trunk/wsm/src/axis/META-INF/services/org.apache.beehive.wsm.databinding.BindingLookupStrategy
URL: http://svn.apache.org/viewcvs/beehive/trunk/wsm/src/axis/META-INF/services/org.apache.beehive.wsm.databinding.BindingLookupStrategy?rev=358023&view=auto
==============================================================================
--- beehive/trunk/wsm/src/axis/META-INF/services/org.apache.beehive.wsm.databinding.BindingLookupStrategy (added)
+++ beehive/trunk/wsm/src/axis/META-INF/services/org.apache.beehive.wsm.databinding.BindingLookupStrategy Tue Dec 20 07:52:53 2005
@@ -0,0 +1 @@
+org.apache.beehive.wsm.axis.databinding.TypeSystemLookupStrategy
\ No newline at end of file

Modified: beehive/trunk/wsm/src/axis/org/apache/beehive/wsm/axis/ServiceDescriptionFactory.java
URL: http://svn.apache.org/viewcvs/beehive/trunk/wsm/src/axis/org/apache/beehive/wsm/axis/ServiceDescriptionFactory.java?rev=358023&r1=358022&r2=358023&view=diff
==============================================================================
--- beehive/trunk/wsm/src/axis/org/apache/beehive/wsm/axis/ServiceDescriptionFactory.java (original)
+++ beehive/trunk/wsm/src/axis/org/apache/beehive/wsm/axis/ServiceDescriptionFactory.java Tue Dec 20 07:52:53 2005
@@ -52,11 +52,11 @@
 import org.apache.axis.utils.BeanPropertyDescriptor;
 import org.apache.axis.utils.BeanUtils;
 import org.apache.axis.Constants;
-import org.apache.beehive.wsm.axis.databinding.TypeSystemLookupService;
+import org.apache.beehive.wsm.axis.databinding.TypeSystemLookupStrategy;
 import org.apache.beehive.wsm.axis.registration.AxisTypeMappingMetaData;
 import org.apache.beehive.wsm.axis.util.encoding.XmlBeanDeserializerFactory;
 import org.apache.beehive.wsm.axis.util.encoding.XmlBeanSerializerFactory;
-import org.apache.beehive.wsm.databinding.BindingLookupService;
+import org.apache.beehive.wsm.databinding.BindingLookupStrategy;
 import org.apache.beehive.wsm.model.BeehiveWsMethodMetadata;
 import org.apache.beehive.wsm.model.BeehiveWsParameterMetadata;
 import org.apache.beehive.wsm.model.BeehiveWsSOAPBindingInfo;
@@ -387,8 +387,8 @@
         /* the type needs to be registered */
         TypeMapping tm = desc.getTypeMapping();
 
-        BindingLookupService lookupService = TypeSystemLookupService.getInstance();
-        QName qname = lookupService.class2qname(type, defaultNamespace);
+        BindingLookupStrategy lookupStrategy = TypeSystemLookupStrategy.getInstance();
+        QName qname = lookupStrategy.class2qname(type, defaultNamespace);
 
         if(type.isArray()) {
             /*

Copied: beehive/trunk/wsm/src/axis/org/apache/beehive/wsm/axis/databinding/AxisLookupStrategy.java (from r357770, beehive/trunk/wsm/src/axis/org/apache/beehive/wsm/axis/databinding/AxisLookupService.java)
URL: http://svn.apache.org/viewcvs/beehive/trunk/wsm/src/axis/org/apache/beehive/wsm/axis/databinding/AxisLookupStrategy.java?p2=beehive/trunk/wsm/src/axis/org/apache/beehive/wsm/axis/databinding/AxisLookupStrategy.java&p1=beehive/trunk/wsm/src/axis/org/apache/beehive/wsm/axis/databinding/AxisLookupService.java&r1=357770&r2=358023&rev=358023&view=diff
==============================================================================
--- beehive/trunk/wsm/src/axis/org/apache/beehive/wsm/axis/databinding/AxisLookupService.java (original)
+++ beehive/trunk/wsm/src/axis/org/apache/beehive/wsm/axis/databinding/AxisLookupStrategy.java Tue Dec 20 07:52:53 2005
@@ -27,10 +27,14 @@
 import org.apache.axis.wsdl.fromJava.Types;
 import org.apache.axis.wsdl.toJava.Utils;
 import org.apache.beehive.wsm.axis.registration.AxisTypeMappingMetaData;
-import org.apache.beehive.wsm.databinding.BindingLookupService;
+import org.apache.beehive.wsm.databinding.BindingLookupStrategy;
 
-public class AxisLookupService
-    implements BindingLookupService {
+/**
+ * Strategy for mapping QName objects to Class objects and vice versa.  This implementation
+ * is specific to Axis 1.x.
+ */
+public class AxisLookupStrategy
+    implements BindingLookupStrategy {
 
     private static final char[] PACKAGE_SEPARATORS = {'.', ':'};
 

Propchange: beehive/trunk/wsm/src/axis/org/apache/beehive/wsm/axis/databinding/AxisLookupStrategy.java
------------------------------------------------------------------------------
    svn:eol-style = native

Copied: beehive/trunk/wsm/src/axis/org/apache/beehive/wsm/axis/databinding/TypeSystemLookupStrategy.java (from r357770, beehive/trunk/wsm/src/axis/org/apache/beehive/wsm/axis/databinding/TypeSystemLookupService.java)
URL: http://svn.apache.org/viewcvs/beehive/trunk/wsm/src/axis/org/apache/beehive/wsm/axis/databinding/TypeSystemLookupStrategy.java?p2=beehive/trunk/wsm/src/axis/org/apache/beehive/wsm/axis/databinding/TypeSystemLookupStrategy.java&p1=beehive/trunk/wsm/src/axis/org/apache/beehive/wsm/axis/databinding/TypeSystemLookupService.java&r1=357770&r2=358023&rev=358023&view=diff
==============================================================================
--- beehive/trunk/wsm/src/axis/org/apache/beehive/wsm/axis/databinding/TypeSystemLookupService.java (original)
+++ beehive/trunk/wsm/src/axis/org/apache/beehive/wsm/axis/databinding/TypeSystemLookupStrategy.java Tue Dec 20 07:52:53 2005
@@ -22,35 +22,35 @@
 import java.util.ArrayList;
 import javax.xml.namespace.QName;
 
-import org.apache.beehive.wsm.databinding.BindingLookupService;
-import org.apache.beehive.wsm.databinding.xmlbeans.XmlBeanLookupService;
+import org.apache.beehive.wsm.databinding.BindingLookupStrategy;
+import org.apache.beehive.wsm.databinding.xmlbeans.XmlBeanLookupStrategy;
 
-public class TypeSystemLookupService
-    implements BindingLookupService {
+public class TypeSystemLookupStrategy
+    implements BindingLookupStrategy {
 
-    private ArrayList<BindingLookupService> _lookupServiceList = new ArrayList<BindingLookupService>();
+    private ArrayList<BindingLookupStrategy> _lookupServiceList = new ArrayList<BindingLookupStrategy>();
 
-    public static BindingLookupService getInstance() {
-        TypeSystemLookupService ts = new TypeSystemLookupService();
-        ts.addBindingLookupService(new XmlBeanLookupService());
-        ts.addBindingLookupService(new AxisLookupService());
+    public static BindingLookupStrategy getInstance() {
+        TypeSystemLookupStrategy ts = new TypeSystemLookupStrategy();
+        ts.addBindingLookupService(new XmlBeanLookupStrategy());
+        ts.addBindingLookupService(new AxisLookupStrategy());
         return ts;
     }
 
-    private TypeSystemLookupService() {
+    private TypeSystemLookupStrategy() {
     }
 
-    public void addBindingLookupService(BindingLookupService bindingLookupService) {
-        _lookupServiceList.add(bindingLookupService);
+    public void addBindingLookupService(BindingLookupStrategy bindingLookupStrategy) {
+        _lookupServiceList.add(bindingLookupStrategy);
     }
 
-    public void removeBindingLookupService(BindingLookupService bindingLookupService) {
-        _lookupServiceList.remove(bindingLookupService);
+    public void removeBindingLookupService(BindingLookupStrategy bindingLookupStrategy) {
+        _lookupServiceList.remove(bindingLookupStrategy);
     }
 
     public QName class2qname(Class clazz) {
-        for(BindingLookupService lookUpService : _lookupServiceList) {
-            QName qname = lookUpService.class2qname(clazz);
+        for(BindingLookupStrategy lookUpStrategy : _lookupServiceList) {
+            QName qname = lookUpStrategy.class2qname(clazz);
             if(qname != null)
                 return qname;
         }
@@ -58,8 +58,8 @@
     }
 
     public QName class2qname(Class clazz, String namespace) {
-        for(BindingLookupService lookUpService : _lookupServiceList) {
-            QName qname = lookUpService.class2qname(clazz, namespace);
+        for(BindingLookupStrategy lookUpStrategy : _lookupServiceList) {
+            QName qname = lookUpStrategy.class2qname(clazz, namespace);
             if(qname != null)
                 return qname;
         }
@@ -67,8 +67,8 @@
     }
 
     public Class qname2class(QName qname) {
-        for(BindingLookupService lookUpService : _lookupServiceList) {
-            Class clazz = lookUpService.qname2class(qname);
+        for(BindingLookupStrategy lookUpStrategy : _lookupServiceList) {
+            Class clazz = lookUpStrategy.qname2class(qname);
             if(clazz != null)
                 return clazz;
         }

Propchange: beehive/trunk/wsm/src/axis/org/apache/beehive/wsm/axis/databinding/TypeSystemLookupStrategy.java
------------------------------------------------------------------------------
    svn:eol-style = native

Modified: beehive/trunk/wsm/src/axis/org/apache/beehive/wsm/axis/tools/Wsdl2AJava.java
URL: http://svn.apache.org/viewcvs/beehive/trunk/wsm/src/axis/org/apache/beehive/wsm/axis/tools/Wsdl2AJava.java?rev=358023&r1=358022&r2=358023&view=diff
==============================================================================
--- beehive/trunk/wsm/src/axis/org/apache/beehive/wsm/axis/tools/Wsdl2AJava.java (original)
+++ beehive/trunk/wsm/src/axis/org/apache/beehive/wsm/axis/tools/Wsdl2AJava.java Tue Dec 20 07:52:53 2005
@@ -20,12 +20,12 @@
 import java.io.IOException;
 import java.net.MalformedURLException;
 
-import org.apache.beehive.wsm.axis.databinding.TypeSystemLookupService;
+import org.apache.beehive.wsm.axis.databinding.TypeSystemLookupStrategy;
 import org.apache.beehive.wsm.model.BeehiveWsTypeMetadata;
 import org.apache.beehive.wsm.model.wsdl.XmlBeanWSDLProcessor;
 import org.apache.beehive.wsm.tools.wsdl2ajava.Model2AJava;
 import org.apache.beehive.wsm.wsdl.Utilities;
-import org.apache.beehive.wsm.databinding.BindingLookupService;
+import org.apache.beehive.wsm.databinding.BindingLookupStrategy;
 import org.apache.xmlbeans.XmlException;
 
 public final class Wsdl2AJava {
@@ -44,10 +44,10 @@
         System.out.println("Base source directory: " + args[1]);
         System.out.println("Processing WSDL: " + args[0]);
 
-        BindingLookupService bindingLookupService = TypeSystemLookupService.getInstance();
+        BindingLookupStrategy bindingLookupStrategy = TypeSystemLookupStrategy.getInstance();
         XmlBeanWSDLProcessor processor;
         try {
-            processor = new XmlBeanWSDLProcessor(Utilities.parseWSDL(args[0]), bindingLookupService);
+            processor = new XmlBeanWSDLProcessor(Utilities.parseWSDL(args[0]), bindingLookupStrategy);
         }
         catch (MalformedURLException e) {
             System.out.println("Unable to find WSDL with URL '" + args[0] + "'.");

Modified: beehive/trunk/wsm/src/core/org/apache/beehive/wsm/databinding/BindingLookupServiceFactory.java
URL: http://svn.apache.org/viewcvs/beehive/trunk/wsm/src/core/org/apache/beehive/wsm/databinding/BindingLookupServiceFactory.java?rev=358023&r1=358022&r2=358023&view=diff
==============================================================================
--- beehive/trunk/wsm/src/core/org/apache/beehive/wsm/databinding/BindingLookupServiceFactory.java (original)
+++ beehive/trunk/wsm/src/core/org/apache/beehive/wsm/databinding/BindingLookupServiceFactory.java Tue Dec 20 07:52:53 2005
@@ -17,13 +17,13 @@
  */
 package org.apache.beehive.wsm.databinding;
 
-import org.apache.beehive.wsm.util.SchemaTypesLookupService;
+import org.apache.beehive.wsm.util.SchemaTypesLookupStrategy;
 
 /**
  *
  */
 public class BindingLookupServiceFactory {
-    public static BindingLookupService builtInTypes() {
-        return new SchemaTypesLookupService();
+    public static BindingLookupStrategy builtInTypes() {
+        return new SchemaTypesLookupStrategy();
     }
 }

Copied: beehive/trunk/wsm/src/core/org/apache/beehive/wsm/databinding/BindingLookupStrategy.java (from r357770, beehive/trunk/wsm/src/core/org/apache/beehive/wsm/databinding/BindingLookupService.java)
URL: http://svn.apache.org/viewcvs/beehive/trunk/wsm/src/core/org/apache/beehive/wsm/databinding/BindingLookupStrategy.java?p2=beehive/trunk/wsm/src/core/org/apache/beehive/wsm/databinding/BindingLookupStrategy.java&p1=beehive/trunk/wsm/src/core/org/apache/beehive/wsm/databinding/BindingLookupService.java&r1=357770&r2=358023&rev=358023&view=diff
==============================================================================
--- beehive/trunk/wsm/src/core/org/apache/beehive/wsm/databinding/BindingLookupService.java (original)
+++ beehive/trunk/wsm/src/core/org/apache/beehive/wsm/databinding/BindingLookupStrategy.java Tue Dec 20 07:52:53 2005
@@ -30,7 +30,7 @@
  * And for a given QName:
  * 		qnameA = class2qname(qname2class(qnameA)
 */
-public interface BindingLookupService {
+public interface BindingLookupStrategy {
 
     QName class2qname(Class cls);
 

Propchange: beehive/trunk/wsm/src/core/org/apache/beehive/wsm/databinding/BindingLookupStrategy.java
------------------------------------------------------------------------------
    svn:eol-style = native

Copied: beehive/trunk/wsm/src/core/org/apache/beehive/wsm/databinding/xmlbeans/XmlBeanLookupStrategy.java (from r357770, beehive/trunk/wsm/src/core/org/apache/beehive/wsm/databinding/xmlbeans/XmlBeanLookupService.java)
URL: http://svn.apache.org/viewcvs/beehive/trunk/wsm/src/core/org/apache/beehive/wsm/databinding/xmlbeans/XmlBeanLookupStrategy.java?p2=beehive/trunk/wsm/src/core/org/apache/beehive/wsm/databinding/xmlbeans/XmlBeanLookupStrategy.java&p1=beehive/trunk/wsm/src/core/org/apache/beehive/wsm/databinding/xmlbeans/XmlBeanLookupService.java&r1=357770&r2=358023&rev=358023&view=diff
==============================================================================
--- beehive/trunk/wsm/src/core/org/apache/beehive/wsm/model/wsdl/XmlBeanWSDLProcessor.java (original)
+++ beehive/trunk/wsm/src/core/org/apache/beehive/wsm/model/wsdl/XmlBeanWSDLProcessor.java Tue Dec 20 07:52:53 2005
@@ -25,7 +25,7 @@
 import javax.jws.soap.SOAPBinding;
 import javax.xml.namespace.QName;
 
-import org.apache.beehive.wsm.databinding.BindingLookupService;
+import org.apache.beehive.wsm.databinding.BindingLookupStrategy;
 import org.apache.beehive.wsm.model.BeehiveWsMethodMetadata;
 import org.apache.beehive.wsm.model.BeehiveWsParameterMetadata;
 import org.apache.beehive.wsm.model.BeehiveWsSOAPBindingInfo;
@@ -67,7 +67,7 @@
     private static final String WSDL_SOAP_NAMESPACE = "http://schemas.xmlsoap.org/wsdl/soap/";
 
     private DefinitionsDocument _defDoc;
-    private BindingLookupService _lookupService;
+    private BindingLookupStrategy _bindingLookupStrategy;
 
     /* private to prevent no-args construction */
     private XmlBeanWSDLProcessor() {
@@ -77,12 +77,12 @@
     /**
      * Create a WSDL processor given a WSDL document and a look-up service for types.
      * @param defDoc
-     * @param lookupService
+     * @param lookupStrategy
      */
-    public XmlBeanWSDLProcessor(DefinitionsDocument defDoc, BindingLookupService lookupService) {
+    public XmlBeanWSDLProcessor(DefinitionsDocument defDoc, BindingLookupStrategy lookupStrategy) {
         this();
         _defDoc = defDoc;
-        _lookupService = lookupService;
+        _bindingLookupStrategy = lookupStrategy;
     }
 
     public QName getServiceName() {
@@ -534,7 +534,7 @@
     }
 
     private String findClassForQname(QName element) {
-        return _lookupService.qname2class(element).getName();
+        return _bindingLookupStrategy.qname2class(element).getName();
     }
 
     /*

Copied: beehive/trunk/wsm/src/core/org/apache/beehive/wsm/util/SchemaTypesLookupStrategy.java (from r357770, beehive/trunk/wsm/src/core/org/apache/beehive/wsm/util/SchemaTypesLookupService.java)
URL: http://svn.apache.org/viewcvs/beehive/trunk/wsm/src/core/org/apache/beehive/wsm/util/SchemaTypesLookupStrategy.java?p2=beehive/trunk/wsm/src/core/org/apache/beehive/wsm/util/SchemaTypesLookupStrategy.java&p1=beehive/trunk/wsm/src/core/org/apache/beehive/wsm/util/SchemaTypesLookupService.java&r1=357770&r2=358023&rev=358023&view=diff
==============================================================================
--- beehive/trunk/wsm/src/core/org/apache/beehive/wsm/util/SchemaTypesLookupService.java (original)
+++ beehive/trunk/wsm/src/core/org/apache/beehive/wsm/util/SchemaTypesLookupStrategy.java Tue Dec 20 07:52:53 2005
@@ -22,13 +22,13 @@
 import java.util.Map;
 import javax.xml.namespace.QName;
 
-import org.apache.beehive.wsm.databinding.BindingLookupService;
+import org.apache.beehive.wsm.databinding.BindingLookupStrategy;
 
 /**
  *
  */
-public class SchemaTypesLookupService
-    implements BindingLookupService {
+public class SchemaTypesLookupStrategy
+    implements BindingLookupStrategy {
 
     private static HashMap<Class, QName> SCHEMA_TYPES = new HashMap<Class, QName>();
 
@@ -50,94 +50,94 @@
         return null;
     }
 
-    private static final String NS_URI_XML = "http://www.w3.org/XML/1998/namespace";
+    public static final String NS_URI_XML = "http://www.w3.org/XML/1998/namespace";
 
-    private static final String URI_1999_SCHEMA_XSD = "http://www.w3.org/1999/XMLSchema";
-    private static final String URI_2000_SCHEMA_XSD = "http://www.w3.org/2000/10/XMLSchema";
-    private static final String URI_2001_SCHEMA_XSD = "http://www.w3.org/2001/XMLSchema";
-    private static final String URI_DEFAULT_SCHEMA_XSD = URI_2001_SCHEMA_XSD;
-
-    private static final String URI_SOAP11_ENC = "http://schemas.xmlsoap.org/soap/encoding/";
-    private static final String URI_SOAP12_ENC = "http://www.w3.org/2003/05/soap-encoding";
-    private static final String URI_DEFAULT_SOAP_ENC = URI_SOAP11_ENC;
+    public static final String URI_1999_SCHEMA_XSD = "http://www.w3.org/1999/XMLSchema";
+    public static final String URI_2000_SCHEMA_XSD = "http://www.w3.org/2000/10/XMLSchema";
+    public static final String URI_2001_SCHEMA_XSD = "http://www.w3.org/2001/XMLSchema";
+    public static final String URI_DEFAULT_SCHEMA_XSD = URI_2001_SCHEMA_XSD;
+
+    public static final String URI_SOAP11_ENC = "http://schemas.xmlsoap.org/soap/encoding/";
+    public static final String URI_SOAP12_ENC = "http://www.w3.org/2003/05/soap-encoding";
+    public static final String URI_DEFAULT_SOAP_ENC = URI_SOAP11_ENC;
 
     public static final String NS_URI_XMLSOAP = "http://xml.apache.org/xml-soap";
 
-    private static final QName XSD_STRING = new QName(URI_DEFAULT_SCHEMA_XSD, "string");
-    private static final QName XSD_BOOLEAN = new QName(URI_DEFAULT_SCHEMA_XSD, "boolean");
-    private static final QName XSD_DOUBLE = new QName(URI_DEFAULT_SCHEMA_XSD, "double");
-    private static final QName XSD_FLOAT = new QName(URI_DEFAULT_SCHEMA_XSD, "float");
-    private static final QName XSD_INT = new QName(URI_DEFAULT_SCHEMA_XSD, "int");
-    private static final QName XSD_INTEGER = new QName(URI_DEFAULT_SCHEMA_XSD, "integer");
-    private static final QName XSD_LONG = new QName(URI_DEFAULT_SCHEMA_XSD, "long");
-    private static final QName XSD_SHORT = new QName(URI_DEFAULT_SCHEMA_XSD, "short");
-    private static final QName XSD_BYTE = new QName(URI_DEFAULT_SCHEMA_XSD, "byte");
-    private static final QName XSD_DECIMAL = new QName(URI_DEFAULT_SCHEMA_XSD, "decimal");
-    private static final QName XSD_BASE64 = new QName(URI_DEFAULT_SCHEMA_XSD, "base64Binary");
-    private static final QName XSD_HEXBIN = new QName(URI_DEFAULT_SCHEMA_XSD, "hexBinary");
-    private static final QName XSD_ANYSIMPLETYPE = new QName(URI_DEFAULT_SCHEMA_XSD, "anySimpleType");
-    private static final QName XSD_ANYTYPE = new QName(URI_DEFAULT_SCHEMA_XSD, "anyType");
-    private static final QName XSD_ANY = new QName(URI_DEFAULT_SCHEMA_XSD, "any");
-    private static final QName XSD_QNAME = new QName(URI_DEFAULT_SCHEMA_XSD, "QName");
-    private static final QName XSD_DATETIME = new QName(URI_DEFAULT_SCHEMA_XSD, "dateTime");
-    private static final QName XSD_DATE = new QName(URI_DEFAULT_SCHEMA_XSD, "date");
-    private static final QName XSD_TIME = new QName(URI_DEFAULT_SCHEMA_XSD, "time");
-    private static final QName XSD_TIMEINSTANT1999 = new QName(URI_1999_SCHEMA_XSD, "timeInstant");
-    private static final QName XSD_TIMEINSTANT2000 = new QName(URI_2000_SCHEMA_XSD, "timeInstant");
-
-    private static final QName XSD_NORMALIZEDSTRING = new QName(URI_2001_SCHEMA_XSD, "normalizedString");
-    private static final QName XSD_TOKEN = new QName(URI_2001_SCHEMA_XSD, "token");
-
-    private static final QName XSD_UNSIGNEDLONG = new QName(URI_2001_SCHEMA_XSD, "unsignedLong");
-    private static final QName XSD_UNSIGNEDINT = new QName(URI_2001_SCHEMA_XSD, "unsignedInt");
-    private static final QName XSD_UNSIGNEDSHORT = new QName(URI_2001_SCHEMA_XSD, "unsignedShort");
-    private static final QName XSD_UNSIGNEDBYTE = new QName(URI_2001_SCHEMA_XSD, "unsignedByte");
-    private static final QName XSD_POSITIVEINTEGER = new QName(URI_2001_SCHEMA_XSD, "positiveInteger");
-    private static final QName XSD_NEGATIVEINTEGER = new QName(URI_2001_SCHEMA_XSD, "negativeInteger");
-    private static final QName XSD_NONNEGATIVEINTEGER = new QName(URI_2001_SCHEMA_XSD, "nonNegativeInteger");
-    private static final QName XSD_NONPOSITIVEINTEGER = new QName(URI_2001_SCHEMA_XSD, "nonPositiveInteger");
-
-    private static final QName XSD_YEARMONTH = new QName(URI_2001_SCHEMA_XSD, "gYearMonth");
-    private static final QName XSD_MONTHDAY = new QName(URI_2001_SCHEMA_XSD, "gMonthDay");
-    private static final QName XSD_YEAR = new QName(URI_2001_SCHEMA_XSD, "gYear");
-    private static final QName XSD_MONTH = new QName(URI_2001_SCHEMA_XSD, "gMonth");
-    private static final QName XSD_DAY = new QName(URI_2001_SCHEMA_XSD, "gDay");
-    private static final QName XSD_DURATION = new QName(URI_2001_SCHEMA_XSD, "duration");
-
-    private static final QName XSD_NAME = new QName(URI_2001_SCHEMA_XSD, "Name");
-    private static final QName XSD_NCNAME = new QName(URI_2001_SCHEMA_XSD, "NCName");
-    private static final QName XSD_NMTOKEN = new QName(URI_2001_SCHEMA_XSD, "NMTOKEN");
-    private static final QName XSD_NMTOKENS = new QName(URI_2001_SCHEMA_XSD, "NMTOKENS");
-    private static final QName XSD_NOTATION = new QName(URI_2001_SCHEMA_XSD, "NOTATION");
-    private static final QName XSD_ENTITY = new QName(URI_2001_SCHEMA_XSD, "ENTITY");
-    private static final QName XSD_ENTITIES = new QName(URI_2001_SCHEMA_XSD, "ENTITIES");
-    private static final QName XSD_IDREF = new QName(URI_2001_SCHEMA_XSD, "IDREF");
-    private static final QName XSD_IDREFS = new QName(URI_2001_SCHEMA_XSD, "IDREFS");
-    private static final QName XSD_ANYURI = new QName(URI_2001_SCHEMA_XSD, "anyURI");
-    private static final QName XSD_LANGUAGE = new QName(URI_2001_SCHEMA_XSD, "language");
-    private static final QName XSD_ID = new QName(URI_2001_SCHEMA_XSD, "ID");
-    private static final QName XSD_SCHEMA = new QName(URI_2001_SCHEMA_XSD, "schema");
-
-    private static final QName XML_LANG = new QName(NS_URI_XML, "lang");
-
-    private static final QName SOAP_BASE64 = new QName(URI_DEFAULT_SOAP_ENC, "base64");
-    private static final QName SOAP_BASE64BINARY = new QName(URI_DEFAULT_SOAP_ENC, "base64Binary");
-    private static final QName SOAP_STRING = new QName(URI_DEFAULT_SOAP_ENC, "string");
-    private static final QName SOAP_BOOLEAN = new QName(URI_DEFAULT_SOAP_ENC, "boolean");
-    private static final QName SOAP_DOUBLE = new QName(URI_DEFAULT_SOAP_ENC, "double");
-    private static final QName SOAP_FLOAT = new QName(URI_DEFAULT_SOAP_ENC, "float");
-    private static final QName SOAP_INT = new QName(URI_DEFAULT_SOAP_ENC, "int");
-    private static final QName SOAP_LONG = new QName(URI_DEFAULT_SOAP_ENC, "long");
-    private static final QName SOAP_SHORT = new QName(URI_DEFAULT_SOAP_ENC, "short");
-    private static final QName SOAP_BYTE = new QName(URI_DEFAULT_SOAP_ENC, "byte");
-    private static final QName SOAP_INTEGER = new QName(URI_DEFAULT_SOAP_ENC, "integer");
-    private static final QName SOAP_DECIMAL = new QName(URI_DEFAULT_SOAP_ENC, "decimal");
-    private static final QName SOAP_ARRAY = new QName(URI_DEFAULT_SOAP_ENC, "Array");
-    private static final QName SOAP_COMMON_ATTRS11 = new QName(URI_SOAP11_ENC, "commonAttributes");
-    private static final QName SOAP_COMMON_ATTRS12 = new QName(URI_SOAP12_ENC, "commonAttributes");
-    private static final QName SOAP_ARRAY_ATTRS11 = new QName(URI_SOAP11_ENC, "arrayAttributes");
-    private static final QName SOAP_ARRAY_ATTRS12 = new QName(URI_SOAP12_ENC, "arrayAttributes");
-    private static final QName SOAP_ARRAY12 = new QName(URI_SOAP12_ENC, "Array");
+    public static final QName XSD_STRING = new QName(URI_DEFAULT_SCHEMA_XSD, "string");
+    public static final QName XSD_BOOLEAN = new QName(URI_DEFAULT_SCHEMA_XSD, "boolean");
+    public static final QName XSD_DOUBLE = new QName(URI_DEFAULT_SCHEMA_XSD, "double");
+    public static final QName XSD_FLOAT = new QName(URI_DEFAULT_SCHEMA_XSD, "float");
+    public static final QName XSD_INT = new QName(URI_DEFAULT_SCHEMA_XSD, "int");
+    public static final QName XSD_INTEGER = new QName(URI_DEFAULT_SCHEMA_XSD, "integer");
+    public static final QName XSD_LONG = new QName(URI_DEFAULT_SCHEMA_XSD, "long");
+    public static final QName XSD_SHORT = new QName(URI_DEFAULT_SCHEMA_XSD, "short");
+    public static final QName XSD_BYTE = new QName(URI_DEFAULT_SCHEMA_XSD, "byte");
+    public static final QName XSD_DECIMAL = new QName(URI_DEFAULT_SCHEMA_XSD, "decimal");
+    public static final QName XSD_BASE64 = new QName(URI_DEFAULT_SCHEMA_XSD, "base64Binary");
+    public static final QName XSD_HEXBIN = new QName(URI_DEFAULT_SCHEMA_XSD, "hexBinary");
+    public static final QName XSD_ANYSIMPLETYPE = new QName(URI_DEFAULT_SCHEMA_XSD, "anySimpleType");
+    public static final QName XSD_ANYTYPE = new QName(URI_DEFAULT_SCHEMA_XSD, "anyType");
+    public static final QName XSD_ANY = new QName(URI_DEFAULT_SCHEMA_XSD, "any");
+    public static final QName XSD_QNAME = new QName(URI_DEFAULT_SCHEMA_XSD, "QName");
+    public static final QName XSD_DATETIME = new QName(URI_DEFAULT_SCHEMA_XSD, "dateTime");
+    public static final QName XSD_DATE = new QName(URI_DEFAULT_SCHEMA_XSD, "date");
+    public static final QName XSD_TIME = new QName(URI_DEFAULT_SCHEMA_XSD, "time");
+    public static final QName XSD_TIMEINSTANT1999 = new QName(URI_1999_SCHEMA_XSD, "timeInstant");
+    public static final QName XSD_TIMEINSTANT2000 = new QName(URI_2000_SCHEMA_XSD, "timeInstant");
+
+    public static final QName XSD_NORMALIZEDSTRING = new QName(URI_2001_SCHEMA_XSD, "normalizedString");
+    public static final QName XSD_TOKEN = new QName(URI_2001_SCHEMA_XSD, "token");
+
+    public static final QName XSD_UNSIGNEDLONG = new QName(URI_2001_SCHEMA_XSD, "unsignedLong");
+    public static final QName XSD_UNSIGNEDINT = new QName(URI_2001_SCHEMA_XSD, "unsignedInt");
+    public static final QName XSD_UNSIGNEDSHORT = new QName(URI_2001_SCHEMA_XSD, "unsignedShort");
+    public static final QName XSD_UNSIGNEDBYTE = new QName(URI_2001_SCHEMA_XSD, "unsignedByte");
+    public static final QName XSD_POSITIVEINTEGER = new QName(URI_2001_SCHEMA_XSD, "positiveInteger");
+    public static final QName XSD_NEGATIVEINTEGER = new QName(URI_2001_SCHEMA_XSD, "negativeInteger");
+    public static final QName XSD_NONNEGATIVEINTEGER = new QName(URI_2001_SCHEMA_XSD, "nonNegativeInteger");
+    public static final QName XSD_NONPOSITIVEINTEGER = new QName(URI_2001_SCHEMA_XSD, "nonPositiveInteger");
+
+    public static final QName XSD_YEARMONTH = new QName(URI_2001_SCHEMA_XSD, "gYearMonth");
+    public static final QName XSD_MONTHDAY = new QName(URI_2001_SCHEMA_XSD, "gMonthDay");
+    public static final QName XSD_YEAR = new QName(URI_2001_SCHEMA_XSD, "gYear");
+    public static final QName XSD_MONTH = new QName(URI_2001_SCHEMA_XSD, "gMonth");
+    public static final QName XSD_DAY = new QName(URI_2001_SCHEMA_XSD, "gDay");
+    public static final QName XSD_DURATION = new QName(URI_2001_SCHEMA_XSD, "duration");
+
+    public static final QName XSD_NAME = new QName(URI_2001_SCHEMA_XSD, "Name");
+    public static final QName XSD_NCNAME = new QName(URI_2001_SCHEMA_XSD, "NCName");
+    public static final QName XSD_NMTOKEN = new QName(URI_2001_SCHEMA_XSD, "NMTOKEN");
+    public static final QName XSD_NMTOKENS = new QName(URI_2001_SCHEMA_XSD, "NMTOKENS");
+    public static final QName XSD_NOTATION = new QName(URI_2001_SCHEMA_XSD, "NOTATION");
+    public static final QName XSD_ENTITY = new QName(URI_2001_SCHEMA_XSD, "ENTITY");
+    public static final QName XSD_ENTITIES = new QName(URI_2001_SCHEMA_XSD, "ENTITIES");
+    public static final QName XSD_IDREF = new QName(URI_2001_SCHEMA_XSD, "IDREF");
+    public static final QName XSD_IDREFS = new QName(URI_2001_SCHEMA_XSD, "IDREFS");
+    public static final QName XSD_ANYURI = new QName(URI_2001_SCHEMA_XSD, "anyURI");
+    public static final QName XSD_LANGUAGE = new QName(URI_2001_SCHEMA_XSD, "language");
+    public static final QName XSD_ID = new QName(URI_2001_SCHEMA_XSD, "ID");
+    public static final QName XSD_SCHEMA = new QName(URI_2001_SCHEMA_XSD, "schema");
+
+    public static final QName XML_LANG = new QName(NS_URI_XML, "lang");
+
+    public static final QName SOAP_BASE64 = new QName(URI_DEFAULT_SOAP_ENC, "base64");
+    public static final QName SOAP_BASE64BINARY = new QName(URI_DEFAULT_SOAP_ENC, "base64Binary");
+    public static final QName SOAP_STRING = new QName(URI_DEFAULT_SOAP_ENC, "string");
+    public static final QName SOAP_BOOLEAN = new QName(URI_DEFAULT_SOAP_ENC, "boolean");
+    public static final QName SOAP_DOUBLE = new QName(URI_DEFAULT_SOAP_ENC, "double");
+    public static final QName SOAP_FLOAT = new QName(URI_DEFAULT_SOAP_ENC, "float");
+    public static final QName SOAP_INT = new QName(URI_DEFAULT_SOAP_ENC, "int");
+    public static final QName SOAP_LONG = new QName(URI_DEFAULT_SOAP_ENC, "long");
+    public static final QName SOAP_SHORT = new QName(URI_DEFAULT_SOAP_ENC, "short");
+    public static final QName SOAP_BYTE = new QName(URI_DEFAULT_SOAP_ENC, "byte");
+    public static final QName SOAP_INTEGER = new QName(URI_DEFAULT_SOAP_ENC, "integer");
+    public static final QName SOAP_DECIMAL = new QName(URI_DEFAULT_SOAP_ENC, "decimal");
+    public static final QName SOAP_ARRAY = new QName(URI_DEFAULT_SOAP_ENC, "Array");
+    public static final QName SOAP_COMMON_ATTRS11 = new QName(URI_SOAP11_ENC, "commonAttributes");
+    public static final QName SOAP_COMMON_ATTRS12 = new QName(URI_SOAP12_ENC, "commonAttributes");
+    public static final QName SOAP_ARRAY_ATTRS11 = new QName(URI_SOAP11_ENC, "arrayAttributes");
+    public static final QName SOAP_ARRAY_ATTRS12 = new QName(URI_SOAP12_ENC, "arrayAttributes");
+    public static final QName SOAP_ARRAY12 = new QName(URI_SOAP12_ENC, "Array");
 
     // unsupported since they're bound to Axis
     /*

Propchange: beehive/trunk/wsm/src/core/org/apache/beehive/wsm/util/SchemaTypesLookupStrategy.java
------------------------------------------------------------------------------
    svn:eol-style = native

Modified: beehive/trunk/wsm/test/src/junit/org/apache/beehive/wsm/axis/handlers/FaultTest.java
URL: http://svn.apache.org/viewcvs/beehive/trunk/wsm/test/src/junit/org/apache/beehive/wsm/axis/handlers/FaultTest.java?rev=358023&r1=358022&r2=358023&view=diff
==============================================================================
--- beehive/trunk/wsm/test/src/junit/org/apache/beehive/wsm/axis/handlers/FaultTest.java (original)
+++ beehive/trunk/wsm/test/src/junit/org/apache/beehive/wsm/axis/handlers/FaultTest.java Tue Dec 20 07:52:53 2005
@@ -42,6 +42,8 @@
 
     public void setUp()
         throws Exception {
+        System.out.println("kickstart...");
+
         String classname = "org.apache.beehive.wsm.axis.FakeDocWebService";
 
         AnnotatedWebServiceDeploymentHandler hdlr = new AnnotatedWebServiceDeploymentHandler();

Modified: beehive/trunk/wsm/test/src/junit/org/apache/beehive/wsm/test/jsr181/wsdl/XmlBeanWSDLProcessorTest.java
URL: http://svn.apache.org/viewcvs/beehive/trunk/wsm/test/src/junit/org/apache/beehive/wsm/test/jsr181/wsdl/XmlBeanWSDLProcessorTest.java?rev=358023&r1=358022&r2=358023&view=diff
==============================================================================
--- beehive/trunk/wsm/test/src/junit/org/apache/beehive/wsm/test/jsr181/wsdl/XmlBeanWSDLProcessorTest.java (original)
+++ beehive/trunk/wsm/test/src/junit/org/apache/beehive/wsm/test/jsr181/wsdl/XmlBeanWSDLProcessorTest.java Tue Dec 20 07:52:53 2005
@@ -21,14 +21,14 @@
 import java.util.Iterator;
 
 import junit.framework.TestCase;
-import org.apache.beehive.wsm.axis.databinding.TypeSystemLookupService;
+import org.apache.beehive.wsm.axis.databinding.TypeSystemLookupStrategy;
 import org.apache.beehive.wsm.model.BeehiveWsMethodMetadata;
 import org.apache.beehive.wsm.model.BeehiveWsParameterMetadata;
 import org.apache.beehive.wsm.model.BeehiveWsTypeMetadata;
 import org.apache.beehive.wsm.model.jsr181.Jsr181ObjectModelStore;
 import org.apache.beehive.wsm.model.wsdl.XmlBeanWSDLProcessor;
 import org.apache.beehive.wsm.wsdl.Utilities;
-import org.apache.beehive.wsm.databinding.BindingLookupService;
+import org.apache.beehive.wsm.databinding.BindingLookupStrategy;
 
 /**
  */
@@ -48,8 +48,8 @@
         InputStream is = null;
         try {
             is = Thread.currentThread().getContextClassLoader().getResourceAsStream("schemas/starwars.wsdl");
-            BindingLookupService bindingLookupService = TypeSystemLookupService.getInstance();
-            XmlBeanWSDLProcessor xbwp = new XmlBeanWSDLProcessor(Utilities.parseWSDL(is), bindingLookupService);
+            BindingLookupStrategy bindingLookupStrategy = TypeSystemLookupStrategy.getInstance();
+            XmlBeanWSDLProcessor xbwp = new XmlBeanWSDLProcessor(Utilities.parseWSDL(is), bindingLookupStrategy);
             clientModel = xbwp.getObjectModel();
         }
         finally {

Added: beehive/trunk/wsm/test/src/junit/org/apache/beehive/wsm/test/types/ClassToQNameTest.java
URL: http://svn.apache.org/viewcvs/beehive/trunk/wsm/test/src/junit/org/apache/beehive/wsm/test/types/ClassToQNameTest.java?rev=358023&view=auto
==============================================================================
--- beehive/trunk/wsm/test/src/junit/org/apache/beehive/wsm/test/types/ClassToQNameTest.java (added)
+++ beehive/trunk/wsm/test/src/junit/org/apache/beehive/wsm/test/types/ClassToQNameTest.java Tue Dec 20 07:52:53 2005
@@ -0,0 +1,37 @@
+/**
+ Copyright 2004 The Apache Software Foundation.
+
+ Licensed under the Apache License, Version 2.0 (the "License");
+ you may not use this file except in compliance with the License.
+ You may obtain a copy of the License at
+
+ http://www.apache.org/licenses/LICENSE-2.0
+
+ Unless required by applicable law or agreed to in writing, software
+ distributed under the License is distributed on an "AS IS" BASIS,
+ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ See the License for the specific language governing permissions and
+ limitations under the License.
+
+ $Header:$
+ */
+package org.apache.beehive.wsm.test.types;
+
+import javax.xml.namespace.QName;
+
+import org.apache.beehive.wsm.databinding.BindingLookupStrategy;
+import org.apache.beehive.wsm.util.SchemaTypesLookupStrategy;
+import junit.framework.TestCase;
+
+/**
+ *
+ */
+public class ClassToQNameTest
+    extends TestCase {
+
+    public void testLong() {
+        BindingLookupStrategy bindingLookupStrategy = new SchemaTypesLookupStrategy();
+        QName qname = bindingLookupStrategy.class2qname(long.class);
+        assertEquals(SchemaTypesLookupStrategy.XSD_LONG, qname);
+    }
+}

Propchange: beehive/trunk/wsm/test/src/junit/org/apache/beehive/wsm/test/types/ClassToQNameTest.java
------------------------------------------------------------------------------
    svn:eol-style = native

Added: beehive/trunk/wsm/test/src/junit/org/apache/beehive/wsm/test/types/QNameToClassTest.java
URL: http://svn.apache.org/viewcvs/beehive/trunk/wsm/test/src/junit/org/apache/beehive/wsm/test/types/QNameToClassTest.java?rev=358023&view=auto
==============================================================================
--- beehive/trunk/wsm/test/src/junit/org/apache/beehive/wsm/test/types/QNameToClassTest.java (added)
+++ beehive/trunk/wsm/test/src/junit/org/apache/beehive/wsm/test/types/QNameToClassTest.java Tue Dec 20 07:52:53 2005
@@ -0,0 +1,50 @@
+/**
+ Copyright 2004 The Apache Software Foundation.
+
+ Licensed under the Apache License, Version 2.0 (the "License");
+ you may not use this file except in compliance with the License.
+ You may obtain a copy of the License at
+
+ http://www.apache.org/licenses/LICENSE-2.0
+
+ Unless required by applicable law or agreed to in writing, software
+ distributed under the License is distributed on an "AS IS" BASIS,
+ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ See the License for the specific language governing permissions and
+ limitations under the License.
+
+ $Header:$
+ */
+package org.apache.beehive.wsm.test.types;
+
+import org.apache.beehive.wsm.util.SchemaTypesLookupStrategy;
+import org.apache.beehive.wsm.databinding.BindingLookupStrategy;
+import org.apache.beehive.wsm.databinding.xmlbeans.XmlBeanLookupStrategy;
+import junit.framework.TestCase;
+
+/**
+ *
+ */
+public class QNameToClassTest
+    extends TestCase {
+
+    public void testPrimitive() {
+        BindingLookupStrategy bindingLookupStrategy = new SchemaTypesLookupStrategy();
+        Class clazz = bindingLookupStrategy.qname2class(SchemaTypesLookupStrategy.XSD_LONG);
+        assertTrue(long.class == clazz);
+    }
+
+    public void testPrimitive_xmlbeans() {
+        BindingLookupStrategy bindingLookupStrategy = new XmlBeanLookupStrategy();
+        Class clazz = bindingLookupStrategy.qname2class(SchemaTypesLookupStrategy.XSD_LONG);
+        assertTrue(long.class == clazz);
+    }
+
+/*
+    public void testWrapped() {
+        BindingLookupStrategy bindingLookupService = new SchemaTypesLookupStrategy();
+        Class clazz = bindingLookupService.qname2class(SchemaTypesLookupStrategy.XSD_LONG);
+        assertTrue(Long.class == clazz);
+    }
+*/
+}

Propchange: beehive/trunk/wsm/test/src/junit/org/apache/beehive/wsm/test/types/QNameToClassTest.java
------------------------------------------------------------------------------
    svn:eol-style = native
--- beehive/trunk/wsm/src/core/org/apache/beehive/wsm/databinding/xmlbeans/XmlBeanLookupService.java (original)
+++ beehive/trunk/wsm/src/core/org/apache/beehive/wsm/databinding/xmlbeans/XmlBeanLookupStrategy.java Tue Dec 20 07:52:53 2005
@@ -22,7 +22,7 @@
 import java.lang.reflect.Method;
 import javax.xml.namespace.QName;
 
-import org.apache.beehive.wsm.databinding.BindingLookupService;
+import org.apache.beehive.wsm.databinding.BindingLookupStrategy;
 import org.apache.xmlbeans.SchemaField;
 import org.apache.xmlbeans.SchemaType;
 import org.apache.xmlbeans.SchemaTypeLoader;
@@ -32,13 +32,13 @@
 import org.apache.commons.logging.LogFactory;
 
 /**
  * XMLBean based implementation fo the {@link BindingLookupService} which provides a mechanims for translating
  * a Java class name to a {@link QName} and a {@link QName} to a Java class.
  */
-public class XmlBeanLookupService
-    implements BindingLookupService {
+public class XmlBeanLookupStrategy
+    implements BindingLookupStrategy {
 
-    private static Log LOGGER = LogFactory.getLog(XmlBeanLookupService.class);
+    private static Log LOGGER = LogFactory.getLog(XmlBeanLookupStrategy.class);
 
     public QName class2qname(Class cls) {
         if(XmlObject.class.isAssignableFrom(cls))

Propchange: beehive/trunk/wsm/src/core/org/apache/beehive/wsm/databinding/xmlbeans/XmlBeanLookupStrategy.java
------------------------------------------------------------------------------
    svn:eol-style = native
@@ -32,13 +32,13 @@
 
 /**
- * XMLBean based implementation fo the {@link BindingLookupService} which provides a mechanims for translating
+ * XMLBean based implementation fo the {@link BindingLookupStrategy} which provides a mechanims for translating
  * a Java class name to a {@link QName} and a {@link QName} to a Java class.
  */

Modified: beehive/trunk/wsm/src/core/org/apache/beehive/wsm/model/wsdl/XmlBeanWSDLProcessor.java
URL: http://svn.apache.org/viewcvs/beehive/trunk/wsm/src/core/org/apache/beehive/wsm/model/wsdl/XmlBeanWSDLProcessor.java?rev=358023&r1=358022&r2=358023&view=diff
==============================================================================